==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/NativeUICheckbox.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUICheckbox = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUICheckbox, _super);
    function NativeUICheckbox() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ap = null;
        return _this;
    }
    NativeUICheckbox.prototype.get_c = function () {
        return 6;
    };
    Object.defineProperty(NativeUICheckbox.prototype, "ar", {
        get: function () {
            var a = this.o(4);
            return a;
        },
        set: function (a) {
            this.ad(4, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUICheckbox.prototype, "as", {
        get: function () {
            var a = this.o(5);
            return a;
        },
        set: function (a) {
            this.ad(5, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUICheckbox.prototype, "aq", {
        get: function () {
            return this.ap;
        },
        set: function (a) {
            var b = this.ap;
            this.ap = a;
            if (this.ap != null) {
                this.w(2, this.ap);
            }
            else {
                this.ab(2, b);
            }
        },
        enumerable: false,
        configurable: true
    });
    NativeUICheckbox.$t = markType(NativeUICheckbox, 'NativeUICheckbox', NativeUIComponent.$);
    return NativeUICheckbox;
}(NativeUIComponent));
export { NativeUICheckbox };

==> igniteui-react-core-18.0.0.tgz: package/esm5/lib/NativeUICheckbox.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUICheckbox = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUICheckbox, _super);
    function NativeUICheckbox() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.at = null;
        return _this;
    }
    NativeUICheckbox.prototype.get_c = function () {
        return 6;
    };
    Object.defineProperty(NativeUICheckbox.prototype, "av", {
        get: function () {
            var a = this.o(4);
            return a;
        },
        set: function (a) {
            this.af(4, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUICheckbox.prototype, "aw", {
        get: function () {
            var a = this.o(5);
            return a;
        },
        set: function (a) {
            this.af(5, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUICheckbox.prototype, "au", {
        get: function () {
            return this.at;
        },
        set: function (a) {
            var b = this.at;
            this.at = a;
            if (this.at != null) {
                this.x(2, this.at);
            }
            else {
                this.ad(2, b);
            }
        },
        enumerable: false,
        configurable: true
    });
    NativeUICheckbox.$t = markType(NativeUICheckbox, 'NativeUICheckbox', NativeUIComponent.$);
    return NativeUICheckbox;
}(NativeUIComponent));
export { NativeUICheckbox };
